;+
; .. _fig5_gustiness_scatter.pro:
;
; ==========================
; fig5_gustiness_scatter.pro
; ==========================
;
; DESCRIPTION
; ===========
;
; .. graphviz::
;
;    digraph fig5_gustiness_scatter {
;       graph [
;       rankdir="LR",
;       ]
;       ws  [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/ws_gustiness_bias.txt"];
;       sst [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/raw_sst_2000_2008_gustiness.txt"];
;
;       figure [shape=ellipse,fontname=Courier,label="${PROJECT_OD}/fig5_gustiness_scatter.ps"];
;
;       fig5_gustiness_scatter [shape=box,
;       fontname=Courier,
;       color=blue,
;       URL="http://forge.ipsl.jussieu.fr/tropflux/browser/trunk/src/paper01/fig5/fig5_gustiness_scatter.pro",
;       label="${TROPFLUX}/src/paper01/fig5/fig5_gustiness_scatter.pro"];
;
;       {ws sst} -> {fig5_gustiness_scatter} -> {figure}
;    }
;
; SEE ALSO
; ========
;
; :ref:`project_profile.sh`
; :ref:`project_init.pro`
;
; EXAMPLES
; ========
;
; ::
;
;  IDL> fig5_gustiness_scatter
;
; TODO
; ====
;
; check results
;
; improve plot
;
; coding rules
;
; get rid of spwan
;
; complete description
;
; handle IO error
;
; EVOLUTIONS
; ==========
;
; $Id$
;
; - pinsard 2011-04-20T15:29:37Z loholt1.ipsl.polytechnique.fr (Linux)
;
;   * work on loholt1
;
; - fplod 20110420T090057Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * make it work on cratos
;   * remove hard coding path
;   * add graphviz
;
; - fplod 20110411T142955Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * minimal header
;
;-
pro fig5_gustiness_scatter
@cm_general
@cm_project
reinitplt, /z,/invert
key_portrait = 1

openps, FILENAME = 'idl.ps'
fi_ws=project_id_env+'wind_gustiness_bias.txt'
res=read_ascii(fi_ws,data_start=1)
ff=res.field01
erai_wind=reform(ff(4,*))
gust=reform(ff(9,*))

print, correlate(erai_wind,gust)

fi_sst=project_id_env+'raw_sst_2000_2008_gustiness.txt'
res=read_ascii(fi_sst,data_start=1)
ff=res.field1
erai_sst=reform(ff(4,*))

print, correlate(erai_sst,gust)

splot, erai_wind, gust, small=[2,3,1], title='a) ERAI Wind Vs Gustiness', $
      xtitle='ERAI wind', ytitle='Cronin gustiness', charsize=1.2, psym=2 , $
      xrange=[0,10], yrange=[0.5,2.5]
ab=linfit(erai_wind, gust,yfit=yfit)
a=float(ab(0)) & b=float(ab(1))
oplot, erai_wind, yfit, thick=3, color=250
cor=correlate(erai_wind,gust)
xyouts, 2,-0.2, 'cor = -0.574303', charsize=1.2
xyouts, 2,-0.4, 'y = -0.212379 x + 2.84459', charsize=1.2
print, a,b

splot, erai_sst, gust, small=[2,3,2],/noer, title='b) ERAI SST Vs Gustiness', $
      xtitle='ERAI SST', ytitle='Cronin gustiness', charsize=1.2, psym=2 , $
      xrange=[22,32], yrange=[0.5,2.5], lct=39, xmin=1, ymin=1
ab=linfit(erai_sst, gust,yfit=yfit)
a=float(ab(0)) & b=float(ab(1))
oplot, erai_sst, yfit, thick=3, color=250
cor=correlate(erai_sst, gust)
xyouts, 21,-0.2, 'cor = 0.803099', charsize=1.2
xyouts, 21,-0.4, 'y = 0.175712 x -3.17303', charsize=1.2
print, a,b
closeps
fig=project_od_env+'fig5_gustiness_scatter.ps'
spawn, 'mv '+psdir+'idl.ps '+fig
spawn, 'gv '+fig
end
